@@ -24,12 +24,15 @@ class resource_spec_base(sb.Spec):
             yield default_account_id
 
         for provided_account in provided_accounts:
-            if provided_account not in accounts:
-                raise BadPolicy("Unknown account specified", account=provided_account, meta=meta)
+            if not provided_account:
+                yield ""
             else:
-                account_id = accounts[provided_account]
+                if provided_account not in accounts:
+                    raise BadPolicy("Unknown account specified", account=provided_account, meta=meta)
+                else:
+                    account_id = accounts[provided_account]
 
-            yield account_id
+                yield account_id
 
     def default_location(self, meta):
         return meta.everything["aws_syncr"].location
@@ -121,7 +124,7 @@ class arn_specs(resource_spec_base):
             raise BadPolicy("Generic arn specified without specifying 'identity'", meta=meta)
 
         location = self.location(meta)
-        identities = sb.listof(sb.string_spec()).normalise(meta.at("identity"), self.resource.get("identity"))
+        identities = sb.listof(sb.formatted(sb.string_spec(), formatter=MergedOptionStringFormatter)).normalise(meta.at("identity"), self.resource.get("identity"))
 
         for account_id in self.accounts(meta):
             for identity in identities:
